ytree\.arbor\.tree\_node\.TreeNode
==================================

.. currentmodule:: ytree.arbor.tree_node

.. autoclass:: TreeNode

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TreeNode.__init__
      ~TreeNode.add_ancestor
      ~TreeNode.clear_fields
      ~TreeNode.pwalk
      ~TreeNode.save_tree
      ~TreeNode.twalk
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TreeNode.ancestors
      ~TreeNode.descids
      ~TreeNode.is_root
      ~TreeNode.nodes
      ~TreeNode.tree_size
      ~TreeNode.uids
   
   